
/**
* 交互详细代码见HtmlJsInterface.java
*/

window.iHealthBridge = {

    /*获取当前app版本*/
    app_version: prompt('appVersion',''),
    /*获取当前app名称*/
    app_name: prompt('appName',''),
   /*获取当前app的平台*/
    app_platform: prompt('appPlatform',''),

    /*打开一个新的webView 加载url*/
    /**
     * [goWebView 打开一个新的webView 加载url]
     * @param  {[String]}   url      [需要加载的URL地址]
     * @param  {[JSONObject or JSONString]}   param    [相关配置]
     *                         				destroy : 是否销毁当前界面
     * @param  {Function} callback [回调方法]
     */
    goWebView: function(url, param, callback) {
        var p = this.parseParam(param);
        p['url'] = url;
        window.LocalJSBridge.invoke('goWebView', p, callback);
    },

    goNative: function(page, param, callback) {
        var p = this.parseParam(param);
        p['page'] = page;
        window.LocalJSBridge.invoke('goNative', p, callback);
    },

    goBack: function(param, callback) {
        var p = this.parseParam(param);
        window.LocalJSBridge.invoke('goBack', p, callback);
    },

    /**
     * [goHistory 调用原生功能, 进行回退功能]
     * @param  {[Object or JSONString]}   param    [跳转配置包含下列参数]
     *         url : 需要回调的url 路径				  必传		如果不传 此方法 = goBack
     *         needRefresh : 是否需要刷新界面			  默认0
     *         inweb	:  是否只在当前web中检索历史记录  默认0
     *
     * @param  {Function} callback [回调方法]
     */
    goHistory: function(param, callback) {
        var p = this.parseParam(param);
        window.LocalJSBridge.invoke('goHistory', p, callback);
    },

    goLogin: function(param, callback) {
        var p = this.parseParam(param);
        window.LocalJSBridge.invoke('goLogin', p, callback);
    },

    toast: function(param) {
        window.LocalJSBridge.invoke('toast', param);
    },

    doAction: function(action, param, callback) {
        var p = this.parseParam(param);
        window.LocalJSBridge.invoke(action, p, callback);
    },

    parseParam: function(param) {

        if (param == null) {
            return {};
        }

        if (typeof(param) === 'string') {
            if (param == "") {
                return {};
            }
            return JSON.parse(param);
        }

        return param;
    }
};

/**
* h5传来的function回调映射
*/
window.LocalJSBridge = {

    invoke: function(name, params, callback) {

        if (typeof name !== 'string') {
            return;
        }

        if (!params) {
            params = {};
        }

        var callbackKey = name;

        if (callback) {
            if (typeof(window.callbacks) == 'undefined') {
                window.callbacks = {};
            }

            window.callbacks[callbackKey] = callback;
            console.log(callbackKey + ' = ' + callback);
        }

        prompt(name,JSON.stringify(params));
    },

    callJsBack: function(message) {

        console.log(message);

        if (!message) {
            return;
        }

        message = JSON.parse(message);

        if (!message) {
            return;
        }

        var callbackKey = message.action;
        if (!callbackKey) {
            return;
        }

        var callback =  window.callbacks[callbackKey];
        console.log(callback);

        if (callback) {
            var params = message.params;
            var success = message.success;

            callback(params, success);
        }
    },

    removeJsBack: function(action) {
        console.log(action);
        if (!action) {
            return;
        }

        window.callbacks[action] = null;
    }
};

